==> aroundme_0_7_1.zip: am_0_7_core/aroundme/components/core/template/barnraiser_01/login.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<?php
if (isset($_REQUEST['change_email'])) {
?>
<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_change_email'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<?php echo $lang['txt_change_email_intro'];?><br />
		</div>
	</div>
</div>
		
<div class="box_bottom">
	<span class="box_bottom_right"></span>
	<span class="box_bottom_left"></span>
</div>
<?php
}
elseif (isset($display) && $display == "dormant") {
?>
<form action="index.php?amn=core_login" method="post" name="frm" id="id_frm">
	
<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_dormant'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_intro_dormant'];?><br />
			</div>
		</div>
	</div>
			
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_activate'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<label for="id_email"><?php echo $lang['txt_email'];?></label>
					<input id="id_email" class="input1" type="text" name="email" size="22" /><br />
				</p>
				
				<p>
					<label for="id_dob"><?php echo $lang['txt_dob'];?></label>
					<?php echo $datedropdown;?><br />
				</p>
					
				<p>
					<label for="id_captcha"><?php echo $lang['txt_captcha_intro'];?></label><br />
				</p>
				
				<p>
					<img src="get_captcha.php" alt="CAPTCHA" class="picture"><br />
				</p>
				
				<p>
					<input id="id_captcha" class="input" type="text" name="captchastring" size="20"><br />
				</p>
					
				<p align="right">
					<input type="submit" name="activate" class="input_submit" value="<?php echo $lang['sub_send'];?>" class="button_urgent" /><br />
				</p>
			</div>
		</div>
	</div>
			
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>
</form>

<?php
}
else { // login box
?>
<form action="index.php?amn=core_login" method="post" name="frm" id="id_frm">
<input type="hidden" name="http_referer" value="<?php if (isset($http_referer)) { echo $http_referer;}?>" />
					
<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_welcome'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_public_introduction'];?><br />
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_login'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($email_change_status) && $email_change_status == "email_changed") {
					echo "<p class='warning_message'>" . $lang['txt_email_updated'] . "</p>";
				}
				elseif (isset($email_change_status) && $email_change_status == "email_not_changed") {
					echo "<p class='warning_message'>" . $lang['txt_email_not_updated'] . "</p>";
				}
				?>
				
				<p>
					<label for="id_email"><?php echo $lang['txt_email'];?></label>
					<input id="id_email" class="input1" type="text" name="email" size="20" value="" style="width: 140px" /><br />
				</p>
				
				<p>
					<label for="id_password"><?php echo $lang['txt_password'];?></label>
					<input id="id_password" class="input1" type="password" name="password" size="12" value="" style="width: 100px" /><br />
				</p>
				
				<p>
					<?php echo $lang['txt_login_note'];?><br />
				</p>
				
				<p align="right">
					<input type="submit" class="input_submit" name="login" value="<?php echo $lang['sub_enter'];?>" class="input_submit" /><br />
				</p>
				
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>
</form>
<?php }?>

==> aroundme_0_7_2.zip: am_0_7_core/aroundme/components/core/template/barnraiser_01/login.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<?php
if (isset($_REQUEST['change_email'])) {
?>
<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_change_email'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<?php echo $lang['txt_change_email_intro'];?><br />
		</div>
	</div>
</div>
		
<div class="box_bottom">
	<span class="box_bottom_right"></span>
	<span class="box_bottom_left"></span>
</div>
<?php
}
elseif (isset($display) && $display == "dormant") {
?>
<form action="index.php?amn=core_login" method="post" name="frm" id="id_frm">
	
<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_dormant'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_intro_dormant'];?><br />
			</div>
		</div>
	</div>
			
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_activate'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<label for="id_email"><?php echo $lang['txt_email'];?></label>
					<input id="id_email" class="input1" type="text" name="email" size="22" /><br />
				</p>
				
				<p>
					<label for="id_dob"><?php echo $lang['txt_dob'];?></label>
					<?php echo $datedropdown;?><br />
				</p>
					
				<p>
					<label for="id_captcha"><?php echo $lang['txt_captcha_intro'];?></label><br />
				</p>
				
				<p>
					<img src="get_captcha.php" alt="CAPTCHA" class="picture"><br />
				</p>
				
				<p>
					<input id="id_captcha" class="input" type="text" name="captchastring" size="20"><br />
				</p>
					
				<p align="right">
					<input type="submit" name="activate" class="input_submit" value="<?php echo $lang['sub_send'];?>" class="button_urgent" /><br />
				</p>
			</div>
		</div>
	</div>
			
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>
</form>

<?php
}
else { // login box
?>
<form action="index.php?amn=core_login" method="post" name="frm" id="id_frm">
<input type="hidden" name="http_referer" value="<?php if (isset($http_referer)) { echo $http_referer;}?>" />
					
<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_welcome'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php echo $lang['txt_public_introduction'];?><br />
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_login'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($email_change_status) && $email_change_status == "email_changed") {
					echo "<p class='warning_message'>" . $lang['txt_email_updated'] . "</p>";
				}
				elseif (isset($email_change_status) && $email_change_status == "email_not_changed") {
					echo "<p class='warning_message'>" . $lang['txt_email_not_updated'] . "</p>";
				}
				?>
				
				<p>
					<label for="id_email"><?php echo $lang['txt_email'];?></label>
					<input id="id_email" class="input1" type="text" name="email" size="20" value="" style="width: 140px" /><br />
				</p>
				
				<p>
					<label for="id_password"><?php echo $lang['txt_password'];?></label>
					<input id="id_password" class="input1" type="password" name="password" size="12" value="" style="width: 100px" /><br />
				</p>
				
				<p>
					<?php echo $lang['txt_login_note'];?><br />
				</p>
				
				<p align="right">
					<input type="submit" class="input_submit" name="login" value="<?php echo $lang['sub_enter'];?>" /><br />
				</p>
				
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>
</form>
<?php }?>
